==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/document.dart <==
part of keyclic_sdk_api.api;

class Document {
  Document({
    this.file,
    this.permission,
    this.id,
    this.createdAt,
    this.type,
    this.links,
  });

  Document.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    file = DocumentFile.fromJson(json['file']);
    permission = DocumentPermission.fromJson(json['permission']);
    id = json['id'];
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    if (createdAt is DateTime && createdAt.isUtc == false) {
      createdAt = DateTime.parse('${createdAt.toIso8601String()}Z');
    }
    type = json['type'];
    links = DocumentLinks.fromJson(json['_links']);
  }

  DocumentFile file;

  DocumentPermission permission;

  String id;

  DateTime createdAt;

  String type;

  DocumentLinks links;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is Document &&
        runtimeType == other.runtimeType &&
        file == other.file &&
        permission == other.permission &&
        id == other.id &&
        createdAt == other.createdAt;
  }

  @override
  int get hashCode =>
      0 ^
      file.hashCode ^
      permission.hashCode ^
      id.hashCode ^
      createdAt.hashCode;

  Map<String, dynamic> toJson() {
    return {
      'file': file,
      'permission': permission,
      'id': id,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'type': type,
      '_links': links,
    };
  }

  @override
  String toString() {
    return 'Document[file=$file, permission=$permission, id=$id, createdAt=$createdAt, type=$type, links=$links, ]';
  }

  static List<Document> listFromJson(List<dynamic> json) {
    return json == null
        ? List<Document>()
        : json.map((value) => Document.fromJson(value)).toList();
  }

  static Map<String, Document> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Document>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = Document.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/document.dart <==
part of keyclic_sdk_api.api;

class Document {
  Document({
    this.links,
    this.createdAt,
    this.file,
    this.id,
    this.permission,
    this.type,
    this.updatedAt,
  });

  Document.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    links = DocumentLinks.fromJson(json['_links']);
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    if (createdAt is DateTime && createdAt.isUtc == false) {
      createdAt = DateTime.parse('${createdAt.toIso8601String()}Z');
    }
    file = DocumentFile.fromJson(json['file']);
    id = json['id'];
    permission = DocumentPermission.fromJson(json['permission']);
    type = json['type'];
    updatedAt =
        json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    if (updatedAt is DateTime && updatedAt.isUtc == false) {
      updatedAt = DateTime.parse('${updatedAt.toIso8601String()}Z');
    }
  }

  DocumentLinks links;

  DateTime createdAt;

  DocumentFile file;

  String id;

  DocumentPermission permission;

  String type;

  DateTime updatedAt;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is Document &&
        runtimeType == other.runtimeType &&
        links == other.links &&
        createdAt == other.createdAt &&
        file == other.file &&
        id == other.id &&
        permission == other.permission &&
        type == other.type &&
        updatedAt == other.updatedAt;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      links.hashCode ^
      createdAt.hashCode ^
      file.hashCode ^
      id.hashCode ^
      permission.hashCode ^
      type.hashCode ^
      updatedAt.hashCode;

  static List<Document> listFromJson(List<dynamic> json) {
    return json == null
        ? <Document>[]
        : json.map((value) => Document.fromJson(value)).toList();
  }

  static Map<String, Document> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Document>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = Document.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      '_links': links,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'file': file,
      'id': id,
      'permission': permission,
      'type': type,
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
    };
  }

  @override
  String toString() {
    return 'Document[links=$links, createdAt=$createdAt, file=$file, id=$id, permission=$permission, type=$type, updatedAt=$updatedAt, ]';
  }
}
